﻿using Hotline.Orders;
using Hotline.Repository.SqlSugar.Extensions;
using Hotline.Share.Dtos.Order;
using Hotline.Share.Requests;
using MapsterMapper;
using Microsoft.AspNetCore.Mvc;
using XF.Domain.Repository;

namespace Hotline.Api.Controllers.OrderModuleControllers
{
    /// <summary>
    /// 工单抄送
    /// </summary>
    public class OrderCarbonCopyController : BaseController
    {
        private readonly IRepository<OrderCarboncopy> _orderccRepository;
        private readonly IMapper _mapper;

        public OrderCarbonCopyController(
            IRepository<OrderCarboncopy> orderccRepository,
            IMapper mapper
        )
        {
            _orderccRepository = orderccRepository;
            _mapper = mapper;
        }

        [HttpGet]
        public async Task<IReadOnlyList<OrderDto>> Query([FromQuery]PagedKeywordRequest dto)
        {
            var orderccs = await _orderccRepository.Queryable()
                .Includes(d => d.Order)
                //todo 按照抄送权限查询
                //.Where(d=> !string.IsNullOrEmpty())
                .WhereIF(!string.IsNullOrEmpty(dto.Keyword), d => d.Order.No == dto.Keyword)
                .ToPageListWithoutTotalAsync(dto, HttpContext.RequestAborted);

            return _mapper.Map<IReadOnlyList<OrderDto>>(orderccs);
        }

        [HttpGet("count")]
        public async Task<int> Count([FromQuery] PagedKeywordRequest dto)
        {
            return await _orderccRepository.Queryable()
                .Includes(d => d.Order)
                .WhereIF(!string.IsNullOrEmpty(dto.Keyword), d => d.Order.No == dto.Keyword)
                .CountAsync(HttpContext.RequestAborted);
        }
    }
}
